# -*- coding: utf-8 -*-

from odoo import models
from . import consts

from markupsafe import Markup


class AccountMove(models.Model):
    _inherit = 'account.move'

    def _invoice_paid_hook(self):
        res = super(AccountMove, self)._invoice_paid_hook()
        for invoice in self:
            products_tmpl_ids = invoice.invoice_line_ids.mapped('sale_line_ids.product_id.product_tmpl_id')
            partner_id = invoice.partner_id.commercial_partner_id
            if invoice.move_type == 'out_refund' and consts.PRODUCT_CATEGORY_PARTNERSHIP in products_tmpl_ids.mapped('categ_id').ids:
                partner_id.write({
                    'grade_id': False,
                    'commission_plan_id': False,
                })
                partner_id.message_post(
                    body=Markup("""Partner grade level reset after invoice (<a href='#' ""data-oe-model='account.move' data-oe-id='%d'>%s</a>) refund validation""") % (invoice.id, invoice.name or 'View Invoice'),
                    partner_ids=partner_id.user_id.partner_id.ids)
            elif consts.PRODUCT_PARTNERSHIP_LEARNING in products_tmpl_ids.ids:
                grade_id = self.env.ref('openerp_portal.res_partner_grade_learning')
                partner_id.write({
                    'grade_id': grade_id.id,
                    'commission_plan_id': grade_id.default_commission_plan_id.id,
                })
                partner_id.message_post(
                    body=Markup("""Partner grade level set to eLearning after invoice (<a href='#' ""data-oe-model='account.move' data-oe-id='%d'>%s</a>) validation""") % (invoice.id, invoice.name or 'View Invoice'),
                    partner_ids=partner_id.user_id.partner_id.ids)
        return res
